@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2013 Daniel Scharrer
+ * Copyright (C) 2011-2015 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -26,6 +26,7 @@
 #include <boost/static_assert.hpp>
 
 #include "setup/version.hpp"
+#include "util/encoding.hpp"
 #include "util/load.hpp"
 #include "util/storedenum.hpp"
 
@@ -216,6 +217,11 @@ void header::load(std::istream & is, const version & version) {
 	} else {
 		close_applications_filter.clear();
 	}
+	if(version >= INNO_VERSION(5, 5, 6)) {
+		is >> util::encoded_string(setup_mutex, version.codepage());
+	} else {
+		setup_mutex.clear();
+	}
 	if(version >= INNO_VERSION(5, 2, 5)) {
 		is >> util::ansi_string(license_text);
 		is >> util::ansi_string(info_before);
@@ -312,7 +318,7 @@ void header::load(std::istream & is, const version & version) {
 	if(version >= INNO_VERSION(4, 2, 2)) {
 		is.read(password_salt, std::streamsize(sizeof(password_salt)));
 	} else {
-		memset(password_salt, 0, sizeof(password_salt));
+		std::memset(password_salt, 0, sizeof(password_salt));
 	}
 	
 	if(version >= INNO_VERSION(4, 0, 0)) {
@@ -405,6 +411,18 @@ void header::load(std::istream & is, const version & version) {
 		uninstall_display_size = 0;
 	}
 	
+	if(version == INNO_VERSION_EXT(5, 5, 0, 1)) {
+		/*
+		 * This is needed to extract an Inno Setup variant (BlackBox v2?) that uses
+		 * the 5.5.0 (unicode) data version string while the format differs:
+		 * The language entries are off by one byte and the EncryptionUsed flag
+		 * gets set while there is no decrypt_dll.
+		 * I'm not sure where exactly this byte goes, but it's after the compression
+		 * type and before EncryptionUsed flag.
+		 * The other values/flags between here and there look sane (mostly default).
+		 */
+		(void)util::load<boost::uint8_t>(is);
+	}
 	
 	stored_flag_reader<flags> flagreader(is, version.bits);
 	
