@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2013 Daniel Scharrer
+ * Copyright (C) 2011-2015 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -18,6 +18,11 @@
  * 3. This notice may not be removed or altered from any source distribution.
  */
 
+/*!
+ * \file
+ *
+ * Structures for the main setup header in Inno Setup files.
+ */
 #ifndef INNOEXTRACT_SETUP_HEADER_HPP
 #define INNOEXTRACT_SETUP_HEADER_HPP
 
@@ -108,6 +113,7 @@ struct header {
 		DisableDirExistsWarning,
 		BackSolid,
 		OverwriteUninstRegEntries
+		
 	);
 	
 	FLAGS(architecture_types,
@@ -145,6 +151,7 @@ struct header {
 	std::string create_uninstall_registry_key;
 	std::string uninstallable;
 	std::string close_applications_filter;
+	std::string setup_mutex;
 	std::string license_text;
 	std::string info_before;
 	std::string info_after;
